%global oname	XyGrib

Name:		xygrib
Version:	1.2.6.1
Release:	%mkrel 3
Summary:	Weather data visualization, GRIB file viewer
License:	GPLv3
Group:		Sciences/Geosciences
Url:		https://opengribs.org/en/xygrib
Source0:	https://github.com/opengribs/XyGrib/archive/v%{version}/XyGrib-%{version}.tar.gz
Patch1:		0001-Make-finding-version-specific-include-dirs-for-openj.patch
Patch2:		0002-Don-t-install-cmake-files-in-the-translation-directo.patch
Patch3:		0003-Fix-installation-on-linux-like-systems.patch
Patch4:		0004-Fix-installation-of-data-on-linux-like-systems.patch
Patch5:		0001-Don-t-set-CMAKE_CXX_FLAGS-for-compile-options.patch
Patch10:	0001-Lib-Proj-enable-deprecates-API.patch
Patch11:	0001-port-to-PROJ-8.0-API.patch
Patch12:	0002-Use-new-libproj-API-if-available.patch

Patch100:	0001-Find-OpenJPEG-2.4.patch
Patch101:	0001-Add-missing-QPainterPath-include.patch
Patch102:	0001-Use-system-g2clib.patch
Patch103:	0001-Use-system-Liberation-TTF-fonts.patch

BuildRequires:	cmake
BuildRequires:  git-core
BuildRequires:  imagemagick
BuildRequires:	ninja
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5LinguistTools)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5PrintSupport)
BuildRequires:	cmake(Qt5Widgets)
BuildRequires:	cmake(Qt5Xml)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(proj)
BuildRequires:  pkgconfig(libopenjpeg1)
BuildRequires:	bzip2-devel
BuildRequires:	libnova-devel
BuildRequires:	g2clib-devel

Provides:	zygrib = 8.0.1-10%{?dist}
Obsoletes:	zygrib < 8.0.1-10
Obsoletes:	zygrib-maps-high < 8.0.1-10

Requires:	proj
Requires:	fonts-ttf-liberation

%description
XyGrib is a Grib file reader and visualizes meteorological data providing an
off-line capability to analyse weather forecasts or hindcasts.

It is intended to be used as a capable weather work station for anyone with a
serious interest in examining weather. This would include members of the
sailing community, private and sport aviators, farmers, weather buffs and many
more.

XyGrib is the continuation of the zyGrib software package with a new team of
volunteers.

%prep
%autosetup -n XyGrib-%{version} -Sgit_am

# Use system g2clib
rm -rf src/g2clib-*/

# Use system liberation fonts
rm -rf data/fonts

%build
%cmake_qt5 -GNinja
%cmake_build

%install
%cmake_install

# use system fonts
rm -rf %{buildroot}%{_datadir}/openGribs/XyGrib/data/fonts/

# desktop file
install -d -m755 %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=%{oname}
GenericName=GRIB file viewer
Comment=Meterological file viewer
Exec=%{oname}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Science;Geoscience;
EOF

# icon
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{24x24,32x32}/apps
convert 'data/img/xyGrib_32.ico[0]' %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert 'data/img/xyGrib_32.ico[1]' %{buildroot}%{_iconsdir}/hicolor/24x24/apps/%{name}.png

%files
%{_bindir}/%{oname}
%dir %{_datadir}/openGribs/
%dir %{_datadir}/openGribs/XyGrib/
%{_datadir}/openGribs/XyGrib/data/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Tue Nov 22 2022 neoclust <neoclust> 1.2.6.1-3.mga9
+ Revision: 1910203
- Add missing buildrequire for  openjpeg

* Wed Aug 10 2022 wally <wally> 1.2.6.1-2.mga9
+ Revision: 1876811
- use system liberation fonts by default
- build with system g2c

* Tue Aug 09 2022 wally <wally> 1.2.6.1-1.mga9
+ Revision: 1876497
- replace zygrib with xygrib 1.2.6.1
- rebuild for libqwt 6.2.0
+ eatdirt <eatdirt>
- Rebuild for new proj

* Tue Apr 05 2022 umeabot <umeabot> 8.0.1-9.mga9
+ Revision: 1844378
- Mageia 9 Mass Rebuild

* Thu Dec 17 2020 umeabot <umeabot> 8.0.1-8.mga8
+ Revision: 1660346
- Rebuild for new Qt5

* Thu Jul 23 2020 daviddavid <daviddavid> 8.0.1-7.mga8
+ Revision: 1608233
- add patch to fix build with Qt 5.15

* Fri Mar 20 2020 eatdirt <eatdirt> 8.0.1-6.mga8
+ Revision: 1558228
- Rebuild for new libproj

* Sat Feb 15 2020 umeabot <umeabot> 8.0.1-5.mga8
+ Revision: 1525189
- Mageia 8 Mass Rebuild

* Tue Apr 02 2019 umeabot <umeabot> 8.0.1-4.mga7
+ Revision: 1385374
- Qt5 Rebuild

* Fri Mar 08 2019 eatdirt <eatdirt> 8.0.1-3.mga7
+ Revision: 1372917
- Rebuild and fix for new libproj 6.0

* Sun Sep 23 2018 umeabot <umeabot> 8.0.1-2.mga7
+ Revision: 1302070
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 daviddavid <daviddavid> 8.0.1-1.mga7
+ Revision: 1220907
- new version: 8.0.1
- port to Qt5
- rename and rediff use-system-qwt patch
- add BR jasper and g2clib

* Sat Mar 17 2018 daviddavid <daviddavid> 6.2.3-9.mga7
+ Revision: 1210002
- rebuild for new proj 5.0.0

* Tue Nov 21 2017 tv <tv> 6.2.3-8.mga7
+ Revision: 1178358
- rebuild for new libproj

* Sat Sep 23 2017 cjw <cjw> 6.2.3-7.mga7
+ Revision: 1158316
- use qmake_qt4 macro in build to fix debug packages

* Fri May 20 2016 tv <tv> 6.2.3-6.mga6
+ Revision: 1017114
- rebuild for new libproj

* Wed Feb 17 2016 umeabot <umeabot> 6.2.3-5.mga6
+ Revision: 963706
- Mageia 6 Mass Rebuild

* Thu Oct 22 2015 daviddavid <daviddavid> 6.2.3-4.mga6
+ Revision: 894086
- fix qmake path (fix build failure)

* Wed Oct 15 2014 umeabot <umeabot> 6.2.3-3.mga5
+ Revision: 748415
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.2.3-2.mga5
+ Revision: 690894
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Sep 04 2014 grenoya <grenoya> 6.2.3-1.mga5
+ Revision: 671926
- new version 6.2.3
- add patch to use system qwt

* Wed May 14 2014 sander85 <sander85> 6.1.4-3.mga5
+ Revision: 622850
- Rebuild for libnova

* Mon Oct 21 2013 umeabot <umeabot> 6.1.4-2.mga4
+ Revision: 541173
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 grenoya <grenoya> 6.1.4-1.mga4
+ Revision: 495316
- new version 6.1.4

* Mon Jan 14 2013 umeabot <umeabot> 5.0.6-2.mga3
+ Revision: 387785
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 20 2011 grenoya <grenoya> 5.0.6-1.mga2
+ Revision: 169780
-add BR on bzip2-devel
- new version 5.0.6
- clean spec
- fix requirement for qwt
- add patch #0 to fix qwt flag
- fix issue of missong maps, cities name...

* Fri Sep 02 2011 tv <tv> 3.9.2-2.mga2
+ Revision: 137794
- make the huge maps subpackage be noarch

* Thu Apr 21 2011 grenoya <grenoya> 3.9.2-1.mga1
+ Revision: 89433
- imported package zygrib

